/***************************************************************************
                          \fn ADM_coreVideoEncoder
                          \brief Base class for video encoder plugin
                             -------------------
    
    copyright            : (C) 2002/2009 by mean
    email                : fixounet@free.fr
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/
#ifndef ADM_CORE_VIDEO_ENCODER_FF_PARAM_H
#define ADM_CORE_VIDEO_ENCODER_FF_PARAM_H


#define ADM_AVCODEC_SETTING_VERSION 3
extern "C" 
{
#include "libavcodec/avcodec.h"
}

#include "FFcodecContext.h"
#endif
